pub enum BeginString {
FIX44,
}Expand description
Represents the FIX protocol version (8) field value.
This field value determines the message format and version-specific rules that apply to subsequent tags in the message.
Variants
FIX44
FIX.4.4 protocol version (8=FIX.4.4).
Implementations
Sourceimpl BeginString
impl BeginString
Sourcepub const fn tag() -> u16
pub const fn tag() -> u16
Returns the tag used for BeginString.